summaryrefslogtreecommitdiff
path: root/TestScripts
diff options
context:
space:
mode:
authorJeffrey Walton <noloader@gmail.com>2021-05-10 14:44:15 -0400
committerJeffrey Walton <noloader@gmail.com>2021-05-10 14:44:15 -0400
commit24601ac9385e35bd471b502ce1ae9ed46879301c (patch)
tree726c35e2a2cc4f14a27ef2e9f2d00c1b9f610c83 /TestScripts
parentadcc89c8755f7844f384d7e90c26ce11c8aa377c (diff)
downloadcryptopp-git-24601ac9385e35bd471b502ce1ae9ed46879301c.tar.gz
Update cryptest-android.sh
Diffstat (limited to 'TestScripts')
-rwxr-xr-xTestScripts/cryptest-android.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/TestScripts/cryptest-android.sh b/TestScripts/cryptest-android.sh
index a433039d..3798eeec 100755
--- a/TestScripts/cryptest-android.sh
+++ b/TestScripts/cryptest-android.sh
@@ -191,13 +191,13 @@ do
touch "${TMPDIR}/build.failed"
fi
# Test PMULL code generation
count=$(${OBJDUMP} --disassemble gcm_simd.o 2>&1 | grep -c -E 'pclmulqdq|pclmullqlq|pclmullqhq|vpclmulqdq')
if [[ "${count}" -gt 16 ]]
then
- echo "${platform} : PMULL ==> SUCCESS" >> "${TMPDIR}/build.log"
+ echo "${platform} : CLMUL ==> SUCCESS" >> "${TMPDIR}/build.log"
else
- echo "${platform} : PMULL ==> FAILURE" >> "${TMPDIR}/build.log"
+ echo "${platform} : CLMUL ==> FAILURE" >> "${TMPDIR}/build.log"
touch "${TMPDIR}/build.failed"
fi
@@ -191,13 +191,13 @@ do
touch "${TMPDIR}/build.failed"
fi
- # Test PMULL code generation
+ # Test CLMUL code generation
count=$(${OBJDUMP} --disassemble gcm_simd.o 2>&1 | grep -c -E 'pclmulqdq|pclmullqlq|pclmullqhq|vpclmulqdq')
if [[ "${count}" -gt 16 ]]